==> kittycad-0.5.1.tar.gz: kittycad-0.5.1/kittycad/models/metadata.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.cache_metadata import CacheMetadata
from ..models.connection import Connection
from ..models.engine_metadata import EngineMetadata
from ..models.environment import Environment
from ..models.executor_metadata import ExecutorMetadata
from ..models.file_system_metadata import FileSystemMetadata
from ..models.point_e_metadata import PointEMetadata
from ..types import UNSET, Unset

EO = TypeVar("EO", bound="Metadata")


@attr.s(auto_attribs=True)
class Metadata:
    """Metadata about our currently running server.

    This is mostly used for internal purposes and debugging."""  # noqa: E501

    cache: Union[Unset, CacheMetadata] = UNSET
    engine: Union[Unset, EngineMetadata] = UNSET
    environment: Union[Unset, Environment] = UNSET
    executor: Union[Unset, ExecutorMetadata] = UNSET
    fs: Union[Unset, FileSystemMetadata] = UNSET
    git_hash: Union[Unset, str] = UNSET
    point_e: Union[Unset, PointEMetadata] = UNSET
    pubsub: Union[Unset, Connection] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        if not isinstance(self.cache, Unset):
            cache = self.cache
        if not isinstance(self.engine, Unset):
            engine = self.engine
        if not isinstance(self.environment, Unset):
            environment = self.environment
        if not isinstance(self.executor, Unset):
            executor = self.executor
        if not isinstance(self.fs, Unset):
            fs = self.fs
        git_hash = self.git_hash
        if not isinstance(self.point_e, Unset):
            point_e = self.point_e
        if not isinstance(self.pubsub, Unset):
            pubsub = self.pubsub

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cache is not UNSET:
            field_dict["cache"] = cache
        if engine is not UNSET:
            field_dict["engine"] = engine
        if environment is not UNSET:
            field_dict["environment"] = environment
        if executor is not UNSET:
            field_dict["executor"] = executor
        if fs is not UNSET:
            field_dict["fs"] = fs
        if git_hash is not UNSET:
            field_dict["git_hash"] = git_hash
        if point_e is not UNSET:
            field_dict["point_e"] = point_e
        if pubsub is not UNSET:
            field_dict["pubsub"] = pubsub

        return field_dict

    @classmethod
    def from_dict(cls: Type[EO], src_dict: Dict[str, Any]) -> EO:
        d = src_dict.copy()
        _cache = d.pop("cache", UNSET)
        cache: Union[Unset, CacheMetadata]
        if isinstance(_cache, Unset):
            cache = UNSET
        else:
            cache = _cache  # type: ignore[arg-type]

        _engine = d.pop("engine", UNSET)
        engine: Union[Unset, EngineMetadata]
        if isinstance(_engine, Unset):
            engine = UNSET
        else:
            engine = _engine  # type: ignore[arg-type]

        _environment = d.pop("environment", UNSET)
        environment: Union[Unset, Environment]
        if isinstance(_environment, Unset):
            environment = UNSET
        else:
            environment = _environment  # type: ignore[arg-type]

        _executor = d.pop("executor", UNSET)
        executor: Union[Unset, ExecutorMetadata]
        if isinstance(_executor, Unset):
            executor = UNSET
        else:
            executor = _executor  # type: ignore[arg-type]

        _fs = d.pop("fs", UNSET)
        fs: Union[Unset, FileSystemMetadata]
        if isinstance(_fs, Unset):
            fs = UNSET
        else:
            fs = _fs  # type: ignore[arg-type]

        git_hash = d.pop("git_hash", UNSET)

        _point_e = d.pop("point_e", UNSET)
        point_e: Union[Unset, PointEMetadata]
        if isinstance(_point_e, Unset):
            point_e = UNSET
        else:
            point_e = _point_e  # type: ignore[arg-type]

        _pubsub = d.pop("pubsub", UNSET)
        pubsub: Union[Unset, Connection]
        if isinstance(_pubsub, Unset):
            pubsub = UNSET
        else:
            pubsub = _pubsub  # type: ignore[arg-type]

        metadata = cls(
            cache=cache,
            engine=engine,
            environment=environment,
            executor=executor,
            fs=fs,
            git_hash=git_hash,
            point_e=point_e,
            pubsub=pubsub,
        )

        metadata.additional_properties = d
        return metadata

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> kittycad-0.5.7.tar.gz: kittycad-0.5.7/kittycad/models/metadata.py <==
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.cache_metadata import CacheMetadata
from ..models.connection import Connection
from ..models.environment import Environment
from ..models.file_system_metadata import FileSystemMetadata
from ..types import UNSET, Unset

IT = TypeVar("IT", bound="Metadata")


@attr.s(auto_attribs=True)
class Metadata:
    """Metadata about our currently running server.

    This is mostly used for internal purposes and debugging."""  # noqa: E501

    cache: Union[Unset, CacheMetadata] = UNSET
    environment: Union[Unset, Environment] = UNSET
    fs: Union[Unset, FileSystemMetadata] = UNSET
    git_hash: Union[Unset, str] = UNSET
    pubsub: Union[Unset, Connection] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        cache: Union[Unset, CacheMetadata] = UNSET
        if not isinstance(self.cache, Unset):
            cache = self.cache
        environment: Union[Unset, Environment] = UNSET
        if not isinstance(self.environment, Unset):
            environment = self.environment
        fs: Union[Unset, FileSystemMetadata] = UNSET
        if not isinstance(self.fs, Unset):
            fs = self.fs
        git_hash = self.git_hash
        pubsub: Union[Unset, Connection] = UNSET
        if not isinstance(self.pubsub, Unset):
            pubsub = self.pubsub

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cache is not UNSET:
            _cache: CacheMetadata = cast(CacheMetadata, cache)
            field_dict["cache"] = _cache.to_dict()
        if environment is not UNSET:
            field_dict["environment"] = environment
        if fs is not UNSET:
            _fs: FileSystemMetadata = cast(FileSystemMetadata, fs)
            field_dict["fs"] = _fs.to_dict()
        if git_hash is not UNSET:
            field_dict["git_hash"] = git_hash
        if pubsub is not UNSET:
            _pubsub: Connection = cast(Connection, pubsub)
            field_dict["pubsub"] = _pubsub.to_dict()

        return field_dict

    @classmethod
    def from_dict(cls: Type[IT], src_dict: Dict[str, Any]) -> IT:
        d = src_dict.copy()
        _cache = d.pop("cache", UNSET)
        cache: Union[Unset, CacheMetadata]
        if isinstance(_cache, Unset):
            cache = UNSET
        if _cache is None:
            cache = UNSET
        else:
            cache = CacheMetadata.from_dict(_cache)

        _environment = d.pop("environment", UNSET)
        environment: Union[Unset, Environment]
        if isinstance(_environment, Unset):
            environment = UNSET
        if _environment is None:
            environment = UNSET
        else:
            environment = _environment

        _fs = d.pop("fs", UNSET)
        fs: Union[Unset, FileSystemMetadata]
        if isinstance(_fs, Unset):
            fs = UNSET
        if _fs is None:
            fs = UNSET
        else:
            fs = FileSystemMetadata.from_dict(_fs)

        git_hash = d.pop("git_hash", UNSET)

        _pubsub = d.pop("pubsub", UNSET)
        pubsub: Union[Unset, Connection]
        if isinstance(_pubsub, Unset):
            pubsub = UNSET
        if _pubsub is None:
            pubsub = UNSET
        else:
            pubsub = Connection.from_dict(_pubsub)

        metadata = cls(
            cache=cache,
            environment=environment,
            fs=fs,
            git_hash=git_hash,
            pubsub=pubsub,
        )

        metadata.additional_properties = d
        return metadata

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
